{% if result.document.coordinates %}
    <a data-latitude="{{ result.document.coordinates.0|floatformat:"4u" }}"
       data-longitude="{{ result.document.coordinates.1|floatformat:"4u" }}"
       title="Map"
       onmouseenter="showMap(this);"
       onmouseout="delMap(this);"><span class="material-symbols-outlined material-symbols-align">location_on</span></a>
{% endif %}
{% if result.highlight.label.snippet %}
    {{ result.highlight.label.snippet|safe }}
{% else %}
    {{ result.document.label }}
{% endif %}
{% if result.document.id %}{{ result.document.id|urlize }}{% endif %}
