{% extends "partials/footer.html" %}
{% load i18n %}
{% block footer-center %}
    <a href="https://www.oeaw.ac.at/acdh/" target="_blank">
        <img id="logo"
             class="icon"
             alt="ACDH Logo"
             title="Austrian Centre for Digital Humanities (ACDH) of the Austrian Academy of Sciences"
             src="https://fundament.acdh.oeaw.ac.at/common-assets/images/acdh_logo.svg" />
    </a>
{% endblock footer-center %}
{% block footer-right %}
    {% url "imprint" as imprint_url %}
    {% if imprint_url %}
        <a href="{{ imprint_url }}">{% translate "Imprint" %}</a>
    {% endif %}
{% endblock footer-right %}
